# Archetype? 

#### Everything you need to build and manage API Subscriptions

Archetype is a powerful, reliable purchase server with cross-platform support. Our open-source framework provides a backend and a wrapper around Stripe to make implementing API keys and creating quotas and subscriptions easy. 

Whether you are building a new API or already have millions of customers, you can use Archetype to:

-   Fetch products, make purchases, and check subscription status with our  [native SDKs](https://docs.archetype.dev/docs/installation).
-   Host and  [configure products](https://docs.archetype.dev/docs/products)  remotely from our dashboard.
-   Analyze the most important metrics for your app business  [in one place](https://docs.archetype.dev/docs/analytics).
-   See customer transaction histories, chart lifetime value, and  [grant promotional subscriptions](https://docs.archetype.dev/docs/customers).

Sign up to  [get started for free](https://beta.archetype.dev/signup).


# Getting started resources

[](https://docs.archetype.dev/docs/welcome#getting-started-resources)

With Archetype, you can keep track of all your app transactions in one place — whether your customers are charged through iOS, Android, or the web. As the single source of truth for your app business, we make sure your users’ subscription status is always up to date.

Here are a few ways to get started:

Jump right in with our  [Quickstart Guide](https://docs.archetype.dev/docs/getting-started)

Use  [our API](https://docs.archetype.dev/reference)  to create or modify customers.

# Ready to start building?

Simplified payments for your API are just a few lines of code away.

## [Sign up to  **launch your API today**](https://app.archetype.dev/signup)

## **[Explore the docs](https://docs.archetype.dev/docs/getting-started)**